@@ -27,17 +27,18 @@ class Keys(object):
     NULL         = '\ue000'
     CANCEL       = '\ue001' #  ^break
     HELP         = '\ue002'
-    BACK_SPACE   = '\ue003'
+    BACKSPACE    = '\ue003'
+    BACK_SPACE   = BACKSPACE
     TAB          = '\ue004'
     CLEAR        = '\ue005'
     RETURN       = '\ue006'
     ENTER        = '\ue007'
     SHIFT        = '\ue008'
-    LEFT_SHIFT   = '\ue008' #  alias
+    LEFT_SHIFT   = SHIFT
     CONTROL      = '\ue009'
-    LEFT_CONTROL = '\ue009' #  alias
+    LEFT_CONTROL = CONTROL
     ALT          = '\ue00a'
-    LEFT_ALT     = '\ue00a' #  alias
+    LEFT_ALT     = ALT
     PAUSE        = '\ue00b'
     ESCAPE       = '\ue00c'
     SPACE        = '\ue00d'
@@ -46,19 +47,19 @@ class Keys(object):
     END          = '\ue010'
     HOME         = '\ue011'
     LEFT         = '\ue012'
-    ARROW_LEFT   = '\ue012' # alias
+    ARROW_LEFT   = LEFT
     UP           = '\ue013'
-    ARROW_UP     = '\ue013' # alias
+    ARROW_UP     = UP
     RIGHT        = '\ue014'
-    ARROW_RIGHT  = '\ue014' #  alias
+    ARROW_RIGHT  = RIGHT
     DOWN         = '\ue015'
-    ARROW_DOWN   = '\ue015' #  alias
+    ARROW_DOWN   = DOWN
     INSERT       = '\ue016'
     DELETE       = '\ue017'
     SEMICOLON    = '\ue018'
     EQUALS       = '\ue019'
 
-    NUMPAD0      = '\ue01a' #  numbe pad  keys
+    NUMPAD0      = '\ue01a' #  number pad keys
     NUMPAD1      = '\ue01b'
     NUMPAD2      = '\ue01c'
     NUMPAD3      = '\ue01d'
